@@ -15,8 +15,6 @@ import (
 	"github.com/docker/docker/client"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-
-	"github.com/aquasecurity/trivy/pkg/commands"
 )
 
 func TestDockerEngine(t *testing.T) {
@@ -33,76 +31,76 @@ func TestDockerEngine(t *testing.T) {
 	}{
 		{
 			name:     "alpine:3.9",
-			imageTag: "alpine:3.9",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:alpine-39",
 			input:    "testdata/fixtures/images/alpine-39.tar.gz",
 			golden:   "testdata/alpine-39.json.golden",
 		},
 		{
 			name:     "alpine:3.9, with high and critical severity",
 			severity: []string{"HIGH", "CRITICAL"},
-			imageTag: "alpine:3.9",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:alpine-39",
 			input:    "testdata/fixtures/images/alpine-39.tar.gz",
 			golden:   "testdata/alpine-39-high-critical.json.golden",
 		},
 		{
 			name:      "alpine:3.9, with .trivyignore",
-			imageTag:  "alpine:3.9",
+			imageTag:  "ghcr.io/aquasecurity/trivy-test-images:alpine-39",
 			ignoreIDs: []string{"CVE-2019-1549", "CVE-2019-14697"},
 			input:     "testdata/fixtures/images/alpine-39.tar.gz",
 			golden:    "testdata/alpine-39-ignore-cveids.json.golden",
 		},
 		{
 			name:     "alpine:3.10",
-			imageTag: "alpine:3.10",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:alpine-310",
 			input:    "testdata/fixtures/images/alpine-310.tar.gz",
 			golden:   "testdata/alpine-310.json.golden",
 		},
 		{
 			name:     "amazonlinux:1",
-			imageTag: "amazonlinux:1",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:amazon-1",
 			input:    "testdata/fixtures/images/amazon-1.tar.gz",
 			golden:   "testdata/amazon-1.json.golden",
 		},
 		{
 			name:     "amazonlinux:2",
-			imageTag: "amazonlinux:2",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:amazon-2",
 			input:    "testdata/fixtures/images/amazon-2.tar.gz",
 			golden:   "testdata/amazon-2.json.golden",
 		},
 		{
 			name:     "almalinux 8",
-			imageTag: "almalinux:8",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:almalinux-8",
 			input:    "testdata/fixtures/images/almalinux-8.tar.gz",
 			golden:   "testdata/almalinux-8.json.golden",
 		},
 		{
 			name:     "rocky linux 8",
-			imageTag: "rockylinux:8",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:rockylinux-8",
 			input:    "testdata/fixtures/images/rockylinux-8.tar.gz",
 			golden:   "testdata/rockylinux-8.json.golden",
 		},
 		{
 			name:     "centos 6",
-			imageTag: "centos:6",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:centos-6",
 			input:    "testdata/fixtures/images/centos-6.tar.gz",
 			golden:   "testdata/centos-6.json.golden",
 		},
 		{
 			name:     "centos 7",
-			imageTag: "centos:7",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:centos-7",
 			input:    "testdata/fixtures/images/centos-7.tar.gz",
 			golden:   "testdata/centos-7.json.golden",
 		},
 		{
 			name:          "centos 7, with --ignore-unfixed option",
-			imageTag:      "centos:7",
+			imageTag:      "ghcr.io/aquasecurity/trivy-test-images:centos-7",
 			ignoreUnfixed: true,
 			input:         "testdata/fixtures/images/centos-7.tar.gz",
 			golden:        "testdata/centos-7-ignore-unfixed.json.golden",
 		},
 		{
 			name:          "centos 7, with --ignore-unfixed option, with medium severity",
-			imageTag:      "centos:7",
+			imageTag:      "ghcr.io/aquasecurity/trivy-test-images:centos-7",
 			ignoreUnfixed: true,
 			severity:      []string{"MEDIUM"},
 			input:         "testdata/fixtures/images/centos-7.tar.gz",
@@ -110,81 +108,81 @@ func TestDockerEngine(t *testing.T) {
 		},
 		{
 			name:     "registry.redhat.io/ubi7",
-			imageTag: "registry.redhat.io/ubi7",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:ubi-7",
 			input:    "testdata/fixtures/images/ubi-7.tar.gz",
 			golden:   "testdata/ubi-7.json.golden",
 		},
 		{
 			name:     "debian buster/10",
-			imageTag: "debian:buster",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:debian-buster",
 			input:    "testdata/fixtures/images/debian-buster.tar.gz",
 			golden:   "testdata/debian-buster.json.golden",
 		},
 		{
 			name:          "debian buster/10, with --ignore-unfixed option",
 			ignoreUnfixed: true,
-			imageTag:      "debian:buster",
+			imageTag:      "ghcr.io/aquasecurity/trivy-test-images:debian-buster",
 			input:         "testdata/fixtures/images/debian-buster.tar.gz",
 			golden:        "testdata/debian-buster-ignore-unfixed.json.golden",
 		},
 		{
 			name:     "debian stretch/9",
-			imageTag: "debian:stretch",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:debian-stretch",
 			input:    "testdata/fixtures/images/debian-stretch.tar.gz",
 			golden:   "testdata/debian-stretch.json.golden",
 		},
 		{
 			name:     "distroless base",
-			imageTag: "gcr.io/distroless/base:latest",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:distroless-base",
 			input:    "testdata/fixtures/images/distroless-base.tar.gz",
 			golden:   "testdata/distroless-base.json.golden",
 		},
 		{
 			name:     "distroless python2.7",
-			imageTag: "gcr.io/distroless/python2.7:latest",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:distroless-python27",
 			input:    "testdata/fixtures/images/distroless-python27.tar.gz",
 			golden:   "testdata/distroless-python27.json.golden",
 		},
 		{
 			name:     "oracle linux 8",
-			imageTag: "oraclelinux:8-slim",
-			input:    "testdata/fixtures/images/oraclelinux-8-slim.tar.gz",
-			golden:   "testdata/oraclelinux-8-slim.json.golden",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:oraclelinux-8",
+			input:    "testdata/fixtures/images/oraclelinux-8.tar.gz",
+			golden:   "testdata/oraclelinux-8.json.golden",
 		},
 		{
 			name:     "ubuntu 18.04",
-			imageTag: "ubuntu:18.04",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:ubuntu-1804",
 			input:    "testdata/fixtures/images/ubuntu-1804.tar.gz",
 			golden:   "testdata/ubuntu-1804.json.golden",
 		},
 		{
 			name:          "ubuntu 18.04, with --ignore-unfixed option",
-			imageTag:      "ubuntu:18.04",
+			imageTag:      "ghcr.io/aquasecurity/trivy-test-images:ubuntu-1804",
 			ignoreUnfixed: true,
 			input:         "testdata/fixtures/images/ubuntu-1804.tar.gz",
 			golden:        "testdata/ubuntu-1804-ignore-unfixed.json.golden",
 		},
 		{
 			name:     "opensuse leap 15.1",
-			imageTag: "opensuse/leap:latest",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:opensuse-leap-151",
 			input:    "testdata/fixtures/images/opensuse-leap-151.tar.gz",
 			golden:   "testdata/opensuse-leap-151.json.golden",
 		},
 		{
 			name:     "photon 3.0",
-			imageTag: "photon:3.0-20190823",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:photon-30",
 			input:    "testdata/fixtures/images/photon-30.tar.gz",
 			golden:   "testdata/photon-30.json.golden",
 		},
 		{
 			name:     "CBL-Mariner 1.0",
-			imageTag: "cblmariner.azurecr.io/base/core:1.0",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:mariner-1.0",
 			input:    "testdata/fixtures/images/mariner-1.0.tar.gz",
 			golden:   "testdata/mariner-1.0.json.golden",
 		},
 		{
 			name:     "busybox with Cargo.lock",
-			imageTag: "busy-cargo:latest",
+			imageTag: "ghcr.io/aquasecurity/trivy-test-images:busybox-with-lockfile",
 			input:    "testdata/fixtures/images/busybox-with-lockfile.tar.gz",
 			golden:   "testdata/busybox-with-lockfile.json.golden",
 		},
@@ -199,6 +197,9 @@ func TestDockerEngine(t *testing.T) {
 	// Set up testing DB
 	cacheDir := initDB(t)
 
+	// Set a temp dir so that modules will not be loaded
+	t.Setenv("XDG_DATA_HOME", cacheDir)
+
 	ctx := context.Background()
 	defer ctx.Done()
 
@@ -230,16 +231,14 @@ func TestDockerEngine(t *testing.T) {
 			tmpDir := t.TempDir()
 			output := filepath.Join(tmpDir, "result.json")
 
-			// run trivy
-			app := commands.NewApp("dev")
-			trivyArgs := []string{"trivy", "--cache-dir", cacheDir, "image",
+			osArgs := []string{"--cache-dir", cacheDir, "image",
 				"--skip-update", "--format=json", "--output", output}
 
 			if tt.ignoreUnfixed {
-				trivyArgs = append(trivyArgs, "--ignore-unfixed")
+				osArgs = append(osArgs, "--ignore-unfixed")
 			}
 			if len(tt.severity) != 0 {
-				trivyArgs = append(trivyArgs,
+				osArgs = append(osArgs,
 					[]string{"--severity", strings.Join(tt.severity, ",")}...,
 				)
 			}
@@ -249,11 +248,12 @@ func TestDockerEngine(t *testing.T) {
 				assert.NoError(t, err, "failed to write .trivyignore")
 				defer os.Remove(trivyIgnore)
 			}
-			trivyArgs = append(trivyArgs, tt.input)
+			osArgs = append(osArgs, tt.input)
 
-			err = app.Run(trivyArgs)
+			// Run Trivy
+			err = execute(osArgs)
 			if tt.wantErr != "" {
-				require.NotNil(t, err)
+				require.Error(t, err)
 				assert.Contains(t, err.Error(), tt.wantErr, tt.name)
 				return
 			}
