@@ -26,7 +26,10 @@ const (
 
 // Run runs a k8s scan
 func Run(ctx context.Context, args []string, opts flag.Options) error {
-	cluster, err := k8s.GetCluster(opts.K8sOptions.ClusterContext)
+	cluster, err := k8s.GetCluster(
+		k8s.WithContext(opts.K8sOptions.ClusterContext),
+		k8s.WithKubeConfig(opts.K8sOptions.KubeConfig),
+	)
 	if err != nil {
 		return xerrors.Errorf("failed getting k8s cluster: %w", err)
 	}
@@ -71,6 +74,7 @@ func run(ctx context.Context, opts flag.Options, cluster string, artifacts []*ar
 	if err != nil {
 		return xerrors.Errorf("k8s scan error: %w", err)
 	}
+
 	if err := report.Write(r, report.Option{
 		Format:     opts.Format,
 		Report:     opts.ReportFormat,
